@@ -11,13 +11,14 @@ use Exporter qw{ import };
 use ExtUtils::Manifest ();
 use File::Find ();
 use File::Glob ();
+use File::Spec;
 use Module::Extract::Use;
 use Module::CoreList;
 use Module::Metadata;
 use Scalar::Util ();
 use Test::More 0.88;
 
-our $VERSION = '0.000_918';
+our $VERSION = '0.000_919';
 
 our @EXPORT_OK = qw{ all_prereq_ok file_prereq_ok prereq_ok };
 our %EXPORT_TAGS = (
@@ -163,7 +164,8 @@ sub all_prereq_ok {
     unless( @file ) {
 	@file = (
 	    ( grep { -d } qw{ blib/arch blib/lib blib/script t } ),
-	    File::Glob::bsd_glob( '*.PL' ),
+	    ( map { File::Spec->abs2rel( $_ ) }
+		File::Glob::bsd_glob( '*.PL' ) ),
 	);
     }
 
